@@ -1,6 +1,10 @@
 # Copyright (c) 2008 Thomas Lotze
 # See also LICENSE.txt
 
+"""Sandboxes of directories and files.
+
+"""
+
 import os
 import os.path
 import shutil
